package codeflies.com.mcc.Payment

import android.os.Bundle
import android.util.Log
import androidx.appcompat.app.AppCompatActivity
import codeflies.com.mcc.databinding.ActivityStripePaymentBinding
import com.github.kittinunf.fuel.httpPost
import com.github.kittinunf.fuel.json.responseJson
import com.github.kittinunf.result.Result
import com.stripe.android.PaymentConfiguration
import com.stripe.android.paymentsheet.PaymentSheet
import com.stripe.android.paymentsheet.PaymentSheetResult

class MainStripePayment : AppCompatActivity() {

    // Declare properties
    private lateinit var binding: ActivityStripePaymentBinding
    private lateinit var paymentSheet: PaymentSheet
    private lateinit var customerConfig: PaymentSheet.CustomerConfiguration
    private lateinit var paymentIntentClientSecret: String

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityStripePaymentBinding.inflate(layoutInflater)
        setContentView(binding.root)

        // Initialize PaymentSheet
        paymentSheet = PaymentSheet(this, ::onPaymentSheetResult)

        // Make HTTP request to fetch payment intent details
        val endpoint = "https://carcoll.localserverpro.com/payment-sheet"
        val params = listOf("currency" to "USD", "amount" to "100")

        endpoint.httpPost(params).responseJson { _, _, result ->
            if (result is Result.Success) {
                val responseJson = result.get().obj()
                paymentIntentClientSecret = responseJson.getString("paymentIntent")
                customerConfig = PaymentSheet.CustomerConfiguration(
                    responseJson.getString("customer"),
                    responseJson.getString("ephemeralKey")
                )
                val publishableKey = responseJson.getString("publishableKey")
                PaymentConfiguration.init(this, publishableKey)

                // After obtaining payment details, enable payment button or proceed with payment
                enablePaymentButton()
            } else {
                // Handle HTTP request failure
                Log.e("MainStripePayment", "Failed to fetch payment details")
            }
        }

        // Set OnClickListener for payment button
        binding.payment.setOnClickListener {
            presentPaymentSheet()
        }
    }

    // Function to handle payment sheet result
    private fun onPaymentSheetResult(paymentSheetResult: PaymentSheetResult) {
        // Handle payment sheet result
        // This function will be called after the payment is completed or canceled
        when (paymentSheetResult) {
            is PaymentSheetResult.Canceled -> {
                Log.d("MainStripePayment", "Payment canceled")
            }
            is PaymentSheetResult.Failed -> {
                Log.e("MainStripePayment", "Payment failed: ${paymentSheetResult.error}")
            }
            is PaymentSheetResult.Completed -> {
                Log.d("MainStripePayment", "Payment completed")
                // You can navigate to the order confirmation screen or perform other actions here
            }
        }
    }

    // Function to present payment sheet
    private fun presentPaymentSheet() {
        // Ensure that paymentIntentClientSecret and customerConfig are initialized
        if (::paymentIntentClientSecret.isInitialized && ::customerConfig.isInitialized) {
            paymentSheet.presentWithPaymentIntent(
                paymentIntentClientSecret,
                PaymentSheet.Configuration(
                    merchantDisplayName = "My merchant name",
                    customer = customerConfig,
                    allowsDelayedPaymentMethods = true
                )
            )
        } else {
            // Handle case where payment details are not yet fetched
            Log.e("MainStripePayment", "Payment details are not yet fetched")
        }
    }

    // Function to enable payment button
    private fun enablePaymentButton() {
        // Enable the payment button once payment details are fetched
        binding.payment.isEnabled = true
    }
}
